# Z.Ai REST Client for Python

![PyPi](https://img.shields.io/pypi/v/zaiclient?color=blue)  

Z.Ai API를 Python 환경에서 간편하게 이용할 수 있는 REST client SDK입니다.

Python 3.8 이상을 사용하는 것을 권장합니다.



## Documentation

SDK에 대한 documentation은 [ZAiDocs](https://docs.zaikorea.org/)에서 확인 가능합니다.



## Installation

이 SDK는 [PyPI](https://pypi.org/project/zaiclient/) 를 통해 배포되어 있습니다. `pip`를 이용해 설치하실 수 있습니다. 

```bash
pip install zaiclient
```
